====================================
ScrapyDD (Scrapy Distributed Daemon)
====================================
Scrapydd is a system for scrapy spiders distributed running and scheduleing system, including server and client agent.


Installing Scrapydd
-------------------
By pip::

    pip install scrapydd

You can also install scrapydd manually:

1. Download compressed package from `github releases`_.
2. Decompress the package
3. Run ``python setup.py install``


Docs
----
The docs is hosted `here`_


.. _here: http://scrapydd.readthedocs.org
